package com.lianxi.core.protocol.pushserver;

import com.lianxi.core.protocol.pushserver.IPushReceiveMessage;

interface IPushMonitor {

    /**
     * 1. 首先通过 Socket 进行 Push Center 以及 Push Server的连接， 这是接收到所有推送消息的源泉。
     *
     * <p>Note: 关于返回值是 String 而不是 boolean 的原因： Socket可能会除了 “状态：连接成功” 和 “状态：连接失败”还会有其他的状态出现。
     * 那么前端可能需要根据这些状态而告知给用户， 故boolean的两种返回结果(true/false) 不能满足现实的需求。
     */
    String connectPushServer();

    /**
     * 2. {@link #connect} 连接成功后， 再将需要接受消息的 callback 注册进来
     * */
    boolean registerCallback(IPushReceiveMessage receiveMsgCallback);

    /**
     * 3. 退出 或者 使用完毕， 将 callback 注销掉。 当RemoteService接收到Push消息后， 就不会通知这个callback了。
     */
	boolean unregisterCallback(IPushReceiveMessage receiveMsgCallback);

    /**
     * 断开PushServer的连接
     */
    boolean disconnectPushServer(String from);

    /**
     * 获取目前push Server的状态， 例如： 可以根据 {@link #setPushStatus} 来设置登录后开始启动连接PushServer； 退出登录后，断开PushServer的连接
     */
    int getPushStatus();

    /**
     * 前端主进程UI， 可根据情况设置 Push Server的属性。
     */
    void setPushStatus(int status);

    /**
     * 检查Push目前的状态。
     */
    void checkStatus(String from);

    /**
     * 获取目前是否与PushServer保持连接
     */
    boolean isPushConnected(String from);

    /**
     * 查看当前心跳包是否存活着
     * true: alive； false：death
     */
    boolean isHeartbeatAlive(String from);
}